pub struct CreateOrgRepositoryParams {Show 13 fields
pub allow_merge_commit: Option<bool>,
pub allow_rebase_merge: Option<bool>,
pub allow_squash_merge: Option<bool>,
pub auto_init: Option<bool>,
pub default_branch: Option<String>,
pub delete_branch_on_merge: Option<bool>,
pub description: Option<String>,
pub gitignores: Option<Vec<String>>,
pub is_template: Option<bool>,
pub license_template: Option<String>,
pub name: Option<String>,
pub private: Option<bool>,
pub visibility: Option<String>,
}Fields
allow_merge_commit: Option<bool>either true to allow merging pull requests with a merge commit, or false to prevent merging pull requests with merge commits.
allow_rebase_merge: Option<bool>either true to allow rebase with explicit merge commits (–no-ff), or false to prevent rebase with explicit merge commits.
allow_squash_merge: Option<bool>either true to allow squash-merging pull requests, or false to prevent squash-merging.
auto_init: Option<bool>Whether the repository should be auto-initialized?
default_branch: Option<String>DefaultBranch of the repository (used when initializes and in template)
delete_branch_on_merge: Option<bool>set to true to delete pr branch after merge by default
description: Option<String>Description of the repository to create
gitignores: Option<Vec<String>>Gitignores is a list of gitignore templates to use
is_template: Option<bool>Whether the repository is template
license_template: Option<String>License to use
name: Option<String>Name of the repository to create
private: Option<bool>Private indicates whether the repository is private
visibility: Option<String>Visibility controls the repository visibility and has priority over Private